from setuptools import setup, find_packages

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

VERSION = '2.5.3' 
DESCRIPTION = """A Python3 program that counts sequence occurences in fastq files."""

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="fast2q", 
        version=VERSION,
        author="Afonso M Bravo",
        author_email="<afonsombravo@hotmail.com>",
        url='https://github.com/afombravo/2FAST2Q',
        description=DESCRIPTION,
        long_description=long_description,
        long_description_content_type='text/markdown',
        packages=find_packages(),
        install_requires=["numpy >= 1.19.2",\
                           "matplotlib >= 3.3.4",\
                           "numba >= 0.53.1",\
                           "psutil",\
                           "argparse",\
                           "datetime",\
                           "tqdm >= 4.59.0",\
                           "dataclasses",\
                           "tk-tools >= 0.1"],
        
        keywords=['CRISPRi', 'CRISPRi-Seq', 'essentiality', "gene fitness"],
        classifiers= [
            "Development Status :: 6 - Mature",
            "Intended Audience :: Science/Research",
            "Programming Language :: Python :: 3",
            "Operating System :: OS Independent",
        ]
)